pub enum Error {
Show 17 variants
Serialize(String, ErrorBacktrace),
Compression(ErrorBacktrace),
EmptyOptional(String, ErrorBacktrace),
KeyNotFound(String, ErrorBacktrace),
KeyExists(String, ErrorBacktrace),
Empty(String, ErrorBacktrace),
IteratorEnd(String, ErrorBacktrace),
NotImplemented(String, ErrorBacktrace),
IllegalState(String, ErrorBacktrace),
IllegalArgument(String, ErrorBacktrace),
Unsupported(String, ErrorBacktrace),
ShuttingDown,
OsError(Error, String, ErrorBacktrace),
Unknown(String, ErrorBacktrace),
InvalidCorpus(String, ErrorBacktrace),
Runtime(String, ErrorBacktrace),
InvalidInput(String, ErrorBacktrace),
}Expand description
Main error struct for LibAFL
Variants
Serialize(String, ErrorBacktrace)
Serialization error
Compression(ErrorBacktrace)
Compression error
EmptyOptional(String, ErrorBacktrace)
Optional val was supposed to be set, but isn’t.
KeyNotFound(String, ErrorBacktrace)
Key not in Map
KeyExists(String, ErrorBacktrace)
Key already exists and should not overwrite
Empty(String, ErrorBacktrace)
No elements in the current item
IteratorEnd(String, ErrorBacktrace)
End of iteration
NotImplemented(String, ErrorBacktrace)
This is not supported (yet)
IllegalState(String, ErrorBacktrace)
You’re holding it wrong
IllegalArgument(String, ErrorBacktrace)
The argument passed to this method or function is not valid
Unsupported(String, ErrorBacktrace)
The performed action is not supported on the current platform
ShuttingDown
Shutting down, not really an error.
OsError(Error, String, ErrorBacktrace)
OS error, wrapping a io::Error
Unknown(String, ErrorBacktrace)
Something else happened
InvalidCorpus(String, ErrorBacktrace)
Error with the corpora
Runtime(String, ErrorBacktrace)
Error specific to a runtime like QEMU or Frida
InvalidInput(String, ErrorBacktrace)
The Input was invalid.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn compression() -> Self
pub fn compression() -> Self
Compression error
Sourcepub fn empty_optional<S>(arg: S) -> Self
pub fn empty_optional<S>(arg: S) -> Self
Optional val was supposed to be set, but isn’t.
Sourcepub fn invalid_input<S>(reason: S) -> Self
pub fn invalid_input<S>(reason: S) -> Self
The Input was invalid
Sourcepub fn key_not_found<S>(arg: S) -> Self
pub fn key_not_found<S>(arg: S) -> Self
Key not in Map
Sourcepub fn key_exists<S>(arg: S) -> Self
pub fn key_exists<S>(arg: S) -> Self
Key already exists in Map
Sourcepub fn iterator_end<S>(arg: S) -> Self
pub fn iterator_end<S>(arg: S) -> Self
End of iteration
Sourcepub fn not_implemented<S>(arg: S) -> Self
pub fn not_implemented<S>(arg: S) -> Self
This is not supported (yet)
Sourcepub fn illegal_state<S>(arg: S) -> Self
pub fn illegal_state<S>(arg: S) -> Self
You’re holding it wrong
Sourcepub fn illegal_argument<S>(arg: S) -> Self
pub fn illegal_argument<S>(arg: S) -> Self
The argument passed to this method or function is not valid
Sourcepub fn shutting_down() -> Self
pub fn shutting_down() -> Self
Shutting down, not really an error.
Sourcepub fn unsupported<S>(arg: S) -> Self
pub fn unsupported<S>(arg: S) -> Self
This operation is not supported on the current architecture or platform
Sourcepub fn last_os_error<S>(msg: S) -> Self
pub fn last_os_error<S>(msg: S) -> Self
OS error from io::Error::last_os_error with additional message
Sourcepub fn invalid_corpus<S>(arg: S) -> Self
pub fn invalid_corpus<S>(arg: S) -> Self
Error with corpora